==> rswipl_9.3.5.1.tar.gz: rswipl/NEWS.md <==
# rswipl 9.3.5.1

maintainance release, fixes problems reported for ASAN/UBSAN

# rswipl 9.3.5

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-5/7425

maintainance release, fixes problems reported for Alpine Linux

# rswipl 9.3.3.1

maintainance release, fixes problems reported for M1mac

remove unit tests from installation

# rswipl 9.3.3

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-3/7311

includes fix for RTools 4.4

# rswipl 9.3.2

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-2-2-9-3-2/7270

adds unit tests during installation

# rswipl 9.1.21

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-21/7075

# rswipl 9.1.20

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-20/7011

# rswipl 9.1.19

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-19/6978

# rswipl 9.1.18

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-18/6936

# rswipl 9.1.17.1

maintainance release, fixes UBSAN errors

# rswipl 9.1.17

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-17/6890

maintainance release, fixes linker warnings on MacOS

# rswipl 9.1.16

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-16/6862

maintainance release, fixes a problem with term.h on MacOS

# rswipl 9.1.15

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-15/6820

maintainance release, fixes valgrind issues

# rswipl 9.1.12

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-12/6754

maintainance release, fixes a problem with clang15 on macOS

# rswipl 9.1.11

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-11/6683

# rswipl 9.1.10

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-10/6562

# rswipl 9.1.9

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-9/6507

# rswipl 9.1.8

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-8/6400

fixed a warning under macOS

# rswipl 9.1.7

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-7/6332

# rswipl 9.1.6

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-6/6233

# rswipl 9.1.4

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-4/6136

# rswipl 9.1.3

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-3/6090

# rswipl 8.5.20

swipl-devel version 8.5.20

==> rswipl_9.3.7.2.tar.gz: rswipl/NEWS.md <==
# rswipl 9.3.7.2

Disable Rcpp::Language until SET-TYPEOF problem has been fixed.

# rswipl 9.3.7.1

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-7/7477

Add unit tests during installation, disable SIGUSR2 in Prolog

# rswipl 9.3.5.1

maintainance release, fixes problems reported for ASAN/UBSAN

# rswipl 9.3.5

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-5/7425

maintainance release, fixes problems reported for Alpine Linux

# rswipl 9.3.3.1

maintainance release, fixes problems reported for M1mac

remove unit tests from installation

# rswipl 9.3.3

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-3/7311

includes fix for RTools 4.4

# rswipl 9.3.2

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-2-2-9-3-2/7270

adds unit tests during installation

# rswipl 9.1.21

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-21/7075

# rswipl 9.1.20

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-20/7011

# rswipl 9.1.19

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-19/6978

# rswipl 9.1.18

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-18/6936

# rswipl 9.1.17.1

maintainance release, fixes UBSAN errors

# rswipl 9.1.17

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-17/6890

maintainance release, fixes linker warnings on MacOS

# rswipl 9.1.16

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-16/6862

maintainance release, fixes a problem with term.h on MacOS

# rswipl 9.1.15

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-15/6820

maintainance release, fixes valgrind issues

# rswipl 9.1.12

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-12/6754

maintainance release, fixes a problem with clang15 on macOS

# rswipl 9.1.11

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-11/6683

# rswipl 9.1.10

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-10/6562

# rswipl 9.1.9

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-9/6507

# rswipl 9.1.8

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-8/6400

fixed a warning under macOS

# rswipl 9.1.7

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-7/6332

# rswipl 9.1.6

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-6/6233

# rswipl 9.1.4

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-4/6136

# rswipl 9.1.3

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-3/6090

# rswipl 8.5.20

swipl-devel version 8.5.20
